.. _api_encoders:

Pixel Data Encoders (:mod:`pydicom.encoders`)
=============================================

:class:`~pydicom.encoders.base.Encoder` class instances for compressing
(7FE0,0010) *Pixel Data*.

.. currentmodule:: pydicom.encoders

.. autosummary::
   :toctree: generated/

   RLELosslessEncoder


Encoder utilities

.. autosummary::
   :toctree: generated/

   get_encoder


Base encoder class used by all encoders

.. currentmodule:: pydicom.encoders.base

.. autosummary::
   :toctree: generated/

   Encoder

.. automodule:: pydicom.encoders
  :members:
